summaryrefslogtreecommitdiffstats
path: root/src/usr/hwpf/plat/fapiPlatHwpInvoker.C
diff options
context:
space:
mode:
Diffstat (limited to 'src/usr/hwpf/plat/fapiPlatHwpInvoker.C')
-rw-r--r--src/usr/hwpf/plat/fapiPlatHwpInvoker.C20
1 files changed, 18 insertions, 2 deletions
diff --git a/src/usr/hwpf/plat/fapiPlatHwpInvoker.C b/src/usr/hwpf/plat/fapiPlatHwpInvoker.C
index e497fa6f1..eb66333fd 100644
--- a/src/usr/hwpf/plat/fapiPlatHwpInvoker.C
+++ b/src/usr/hwpf/plat/fapiPlatHwpInvoker.C
@@ -111,8 +111,24 @@ errlHndl_t rcToErrl(ReturnCode i_rc)
}
else
{
- // TODO Iterate through callouts, adding each callout to the
- // error log
+ // Iterate through callouts, adding each callout to the error
+ // log
+ for (ErrorInfoRecord::ErrorInfoCalloutItr_t l_itr =
+ l_record.iv_callouts.begin();
+ l_itr != l_record.iv_callouts.end(); ++l_itr)
+ {
+ // TODO Add callouts to error log
+ FAPI_ERR("rcToErrl: Adding callout TBD");
+ }
+
+ // Iterate through gard requests performing gard
+ for (ErrorInfoRecord::ErrorInfoGardItr_t l_itr =
+ l_record.iv_gards.begin();
+ l_itr != l_record.iv_gards.end(); ++l_itr)
+ {
+ // TODO Gard component
+ FAPI_ERR("rcToErrl: Garding TBD");
+ }
// Iterate through FFDC sections, collecting and adding FFDC to
// the error log
OpenPOWER on IntegriCloud